@@ -6,7 +6,7 @@ BEGIN {
     use Graph::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = 0.02;
+    $VERSION  = 0.03;
     @ISA      = qw (Graph::Template::Base);
 }
 
@@ -35,8 +35,10 @@ sub param
 
     (@_ % 2)
         && die __PACKAGE__, "->param() : Odd number of parameters to param()\n";
-    my %x = @_;
-    @{$self->{PARAM_MAP}}{keys %x} = @x{keys %x};
+
+    my %params = @_;
+    $params{uc $_} = delete $params{$_} for keys %params;
+    @{$self->{PARAM_MAP}}{keys %params} = @params{keys %params};
 
     return 1;
 }
